Finance Module
==============

The finance module provides financial mathematics tools including interest theory, yield curves, and duration/convexity calculations.

.. automodule:: actuneo.finance
   :members:
   :undoc-members:
   :show-inheritance:

InterestTheory
--------------

.. autoclass:: actuneo.finance.InterestTheory
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

YieldCurve
----------

.. autoclass:: actuneo.finance.YieldCurve
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

DurationConvexity
-----------------

.. autoclass:: actuneo.finance.DurationConvexity
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

